/* This is free software. See COPYING for details. */
#include <avr/pgmspace.h>
#include <avr/interrupt.h>
#include <avr/power.h>
#include <avr/sleep.h>
#include <util/delay.h>
#include <uWireM/uWireM.h>
#include <matrix8x8/matrix8x8.h>
#include <hmc5883l/hmc5883l.h>
#include "bitmap.h"
#include "calibrate.h"
#include "heading.h"

#define BRIGHTNESS 10 /* 0=dim, 15=max */
#define ARC (FIXEDPT_BRAD_SEMICIRC >> 3) /* one sixteenth of a circle */

int main(void) {
   calibration_t calib;
   hmc5883l_pos_t p;
   fixedpt_t hdg;

   power_timer1_disable(); /* turn off to save power */
   power_adc_disable();    /* likewise */
   uWireM_init();          /* set up I2C communication library */

   matrix8x8_init(BRIGHTNESS); /* set up 8x8 LED matrix */
   hmc5883l_init(); /* set up magnetometer */
bitmap_show(BITMAP_ONE);
   calibrate(&calib);

   while(1) {
      hmc5883l_read(&p);
      hdg = heading(&p, &calib);
      if(hdg < ARC) bitmap_show(BITMAP_N);
      else if(hdg < ARC*3) bitmap_show(BITMAP_NE);
      else if(hdg < ARC*5) bitmap_show(BITMAP_E);
      else if(hdg < ARC*7) bitmap_show(BITMAP_SE);
      else if(hdg < ARC*9) bitmap_show(BITMAP_S);
      else if(hdg < ARC*11) bitmap_show(BITMAP_SW);
      else if(hdg < ARC*13) bitmap_show(BITMAP_W);
      else if(hdg < ARC*15) bitmap_show(BITMAP_NW);
      else bitmap_show(BITMAP_N);
   }
   return 0;
}
